@@ -82,7 +82,7 @@ extern void preprocessor_cc_free_level(ConditionalConfig **cc_list, int level);
 extern void preprocessor_cc_free_list(ConditionalConfig *cc);
 extern void preprocessor_resolve_conditionals_ce(ConfigEntry **ce_list, PreprocessorPhase phase);
 extern void preprocessor_resolve_conditionals_all(PreprocessorPhase phase);
-extern void free_config_defines(void);
+extern void init_config_defines(void);
 extern void preprocessor_replace_defines(char **item, ConfigEntry *ce);
 
 /*
@@ -445,6 +445,7 @@ extern void del_whowas_from_list(WhoWas **, WhoWas *);
 extern uint64_t hash_whowas_name(const char *name);
 extern void create_whowas_entry(Client *client, WhoWas *e, WhoWasEvent event);
 extern void free_whowas_fields(WhoWas *e);
+extern void free_whowas_entry(WhoWas *e);
 extern int add_to_client_hash_table(const char *, Client *);
 extern int del_from_client_hash_table(const char *, Client *);
 extern int add_to_id_hash_table(const char *, Client *);
@@ -716,6 +717,7 @@ extern int unreal_copyfile(const char *src, const char *dest);
 extern int unreal_copyfileex(const char *src, const char *dest, int tryhardlink);
 extern time_t unreal_getfilemodtime(const char *filename);
 extern void unreal_setfilemodtime(const char *filename, time_t mtime);
+extern int unreal_touch(const char *filename, time_t mtime);
 extern void DeleteTempModules(void);
 extern MODVAR Extban *extbaninfo;
 extern Extban *findmod_by_bantype(const char *str, const char **remainder);
@@ -899,7 +901,7 @@ extern MODVAR char *(*tkl_uhost)(TKL *tkl, char *buf, size_t buflen, int options
 extern MODVAR void (*do_unreal_log_remote_deliver)(LogLevel loglevel, const char *subsystem, const char *event_id, MultiLine *msg, const char *json_serialized);
 extern MODVAR char *(*get_chmodes_for_user)(Client *client, const char *flags);
 extern MODVAR WhoisConfigDetails (*whois_get_policy)(Client *client, Client *target, const char *name);
-extern MODVAR int (*make_oper)(Client *client, const char *operblock_name, const char *operclass, ConfigItem_class *clientclass, long modes, const char *snomask, const char *vhost);
+extern MODVAR int (*make_oper)(Client *client, const char *operblock_name, const char *operclass, ConfigItem_class *clientclass, long modes, const char *snomask, const char *vhost, const char *autojoin_channels);
 extern MODVAR int (*unreal_match_iplist)(Client *client, NameList *l);
 extern MODVAR void (*webserver_send_response)(Client *client, int status, char *msg);
 extern MODVAR void (*webserver_close_client)(Client *client);
@@ -921,14 +923,17 @@ extern MODVAR void (*cancel_ident_lookup)(Client *client);
 extern MODVAR int (*spamreport)(Client *client, const char *ip, NameValuePrioList *details, const char *spamreport_block, Client *by);
 extern MODVAR int (*crule_test)(const char *rule);
 extern MODVAR CRuleNode *(*crule_parse)(const char *rule);
-extern int (*crule_eval)(crule_context *context, CRuleNode *rule);
+extern MODVAR int (*crule_eval)(crule_context *context, CRuleNode *rule);
 #define safe_crule_free(x) do { if (x) crule_free(&x); } while(0)
-extern void (*crule_free)(CRuleNode **);
-extern const char *(*crule_errstring)(int errcode);
-extern void (*ban_act_set_reputation)(Client *client, BanAction *action);
-extern const char *(*get_central_api_key)(void);
-extern int (*central_spamreport)(Client *target, Client *by);
-extern int (*central_spamreport_enabled)(void);
+extern MODVAR void (*crule_free)(CRuleNode **);
+extern MODVAR const char *(*crule_errstring)(int errcode);
+extern MODVAR void (*ban_act_set_reputation)(Client *client, BanAction *action);
+extern MODVAR const char *(*get_central_api_key)(void);
+extern MODVAR int (*central_spamreport)(Client *target, Client *by);
+extern MODVAR int (*central_spamreport_enabled)(void);
+extern MODVAR void (*sasl_succeeded)(Client *client);
+extern MODVAR void (*sasl_failed)(Client *client);
+extern MODVAR int (*decode_authenticate_plain)(const char *param, char **authorization_id, char **authentication_id, char **passwd);
 /* /Efuncs */
 
 /* TLS functions */
@@ -964,7 +969,7 @@ extern int add_silence_default_handler(Client *client, const char *mask, int sen
 extern int del_silence_default_handler(Client *client, const char *mask);
 extern int is_silenced_default_handler(Client *client, Client *acptr);
 extern void do_unreal_log_remote_deliver_default_handler(LogLevel loglevel, const char *subsystem, const char *event_id, MultiLine *msg, const char *json_serialized);
-extern int make_oper_default_handler(Client *client, const char *operblock_name, const char *operclass, ConfigItem_class *clientclass, long modes, const char *snomask, const char *vhost);
+extern int make_oper_default_handler(Client *client, const char *operblock_name, const char *operclass, ConfigItem_class *clientclass, long modes, const char *snomask, const char *vhost, const char *autojoin_channels);
 extern void webserver_send_response_default_handler(Client *client, int status, char *msg);
 extern void webserver_close_client_default_handler(Client *client);
 extern int webserver_handle_body_default_handler(Client *client, WebRequest *web, const char *readbuf, int length);
@@ -986,6 +991,9 @@ extern void ban_act_set_reputation_default_handler(Client *client, BanAction *ac
 extern const char *get_central_api_key_default_handler(void);
 extern int central_spamreport_default_handler(Client *target, Client *by);
 extern int central_spamreport_enabled_default_handler(void);
+extern void sasl_succeeded_default_handler(Client *client);
+extern void sasl_failed_default_handler(Client *client);
+extern int decode_authenticate_plain_default_handler(const char *param, char **authorization_id, char **authentication_id, char **passwd);
 /* End of default handlers for efunctions */
 
 extern MODVAR MOTDFile opermotd, svsmotd, motd, botmotd, smotd, rules;
@@ -1135,6 +1143,7 @@ extern void concat_params(char *buf, int len, int parc, const char *parv[]);
 extern void charsys_check_for_changes(void);
 extern void dns_check_for_changes(void);
 extern MODVAR int maxclients;
+extern MODVAR int reserved_fds;
 extern int fast_badword_match(ConfigItem_badword *badword, const char *line);
 extern int fast_badword_replace(ConfigItem_badword *badword, const char *line, char *buf, int max);
 extern const char *stripbadwords(const char *str, ConfigItem_badword *start_bw, int *blocked);
@@ -1298,6 +1307,8 @@ extern int conf_match_block(ConfigFile *conf, ConfigEntry *ce, SecurityGroup **b
 extern int test_extended_list(Extban *extban, ConfigEntry *cep, int *errors);
 extern int test_set_security_group(ConfigFile *conf, ConfigEntry *ce);
 extern int config_set_security_group(ConfigFile *conf, ConfigEntry *ce);
+extern int user_matches_extended_server_ban(Client *client, const char *name, const char *value);
+extern int user_matches_extended_list(Client *client, NameValuePrioList *e);
 /* securitygroup.c end */
 /* src/unrealdb.c start */
 extern UnrealDB *unrealdb_open(const char *filename, UnrealDBMode mode, char *secret_block);
@@ -1411,6 +1422,7 @@ extern int downloads_in_progress(void);
 extern char *collapse(char *pattern);
 extern void clear_scache_hash_table(void);
 extern void sendto_one(Client *, MessageTag *mtags, FORMAT_STRING(const char *), ...) __attribute__((format(printf,3,4)));
+extern void vsendto_one(Client *to, MessageTag *mtags, const char *pattern, va_list vl);
 extern void mark_data_to_send(Client *to);
 extern EVENT(garbage_collect);
 extern EVENT(loop_event);
