@@ -801,7 +801,7 @@ int InitUnrealIRCd(int argc, char *argv[])
 #ifndef _WIN32
 	fprintf(stderr, "\n");
 	fprintf(stderr, "This server can handle %d concurrent sockets (%d clients + %d reserve)\n\n",
-		maxclients+CLIENTS_RESERVE, maxclients, CLIENTS_RESERVE);
+		maxclients+reserved_fds, maxclients, reserved_fds);
 #endif
 	init_CommandHash();
 	initwhowas();
@@ -824,7 +824,6 @@ int InitUnrealIRCd(int argc, char *argv[])
 	default_class->sendq = DEFAULT_RECVQ;
 	default_class->name = "default";
 	AddListItem(default_class, conf_class);
-	free_config_defines();
 	if (config_read_start() < 0)
 		exit(-1);
 	while (!is_config_read_finished())
