@@ -1808,7 +1808,9 @@ void do_unreal_log_remote_deliver_default_handler(LogLevel loglevel, const char
 {
 }
 
-int make_oper_default_handler(Client *client, const char *operblock_name, const char *operclass, ConfigItem_class *clientclass, long modes, const char *snomask, const char *vhost)
+int make_oper_default_handler(Client *client, const char *operblock_name, const char *operclass,
+                              ConfigItem_class *clientclass, long modes, const char *snomask,
+                              const char *vhost, const char *autojoin_channels)
 {
 	return 0;
 }
@@ -1907,6 +1909,20 @@ int central_spamreport_enabled_default_handler(void)
 	return 0;
 }
 
+void sasl_succeeded_default_handler(Client *client)
+{
+}
+
+void sasl_failed_default_handler(Client *client)
+{
+}
+
+int decode_authenticate_plain_default_handler(const char *param, char **authorization_id, char **authentication_id, char **passwd)
+{
+	return 0;
+}
+
+
 /** my_timegm: mktime()-like function which will use GMT/UTC.
  * Strangely enough there is no standard function for this.
  * On some *NIX OS's timegm() may be available, sometimes only
