@@ -24,21 +24,24 @@ ModuleHeader MOD_HEADER
 	"4.2",
 	"Extban ~j - prevent join only",
 	"UnrealIRCd Team",
-	"unrealircd-5",
+	"unrealircd-6",
 };
 
 /* Forward declarations */
-int extban_modej_is_banned(Client *client, Channel *channel, char *banin, int type, char **msg, char **errmsg);
+int extban_modej_is_banned(BanContext *b);
 
 /** Called upon module init */
 MOD_INIT()
 {
 	ExtbanInfo req;
 	
-	req.flag = 'j';
+	memset(&req, 0, sizeof(req));
+	req.letter = 'j';
+	req.name = "join";
 	req.is_ok = extban_is_ok_nuh_extban;
 	req.conv_param = extban_conv_param_nuh_or_extban;
 	req.is_banned = extban_modej_is_banned;
+	req.is_banned_events = BANCHK_JOIN;
 	req.options = EXTBOPT_ACTMODIFIER;
 	if (!ExtbanAdd(modinfo->handle, req))
 	{
@@ -64,15 +67,7 @@ MOD_UNLOAD()
 }
 
 /** This ban that affects JOINs only */
-int extban_modej_is_banned(Client *client, Channel *channel, char *banin, int type, char **msg, char **errmsg)
+int extban_modej_is_banned(BanContext *b)
 {
-	char *sub_ban;
-
-	if (type != BANCHK_JOIN)
-		return 0;
-
-	sub_ban = banin + 3;
-
-	return ban_check_mask(client, channel, sub_ban, type, msg, errmsg, 0);
+	return ban_check_mask(b);
 }
-
