@@ -340,7 +340,7 @@ static void parse2(Client *cptr, Client **fromptr, MessageTag *mtags, int mtags_
 			ch++;
 	}
 
-	RunHook(HOOKTYPE_PRE_COMMAND, from, mtags, ch);
+	RunHookReturn(HOOKTYPE_PRE_COMMAND, !=0, from, mtags, ch);
 
 	if (*ch == '\0')
 	{
@@ -602,8 +602,8 @@ static void ban_handshake_data_flooder(Client *client)
 	}
 	else
 	{
-		/* place_host_ban also takes care of removing any other clients with same host/ip */
-		place_host_ban(client, iConf.handshake_data_flood_ban_action, "Handshake data flood detected", iConf.handshake_data_flood_ban_time);
+		/* take_action also takes care of removing any other clients with same host/ip */
+		take_action(client, iConf.handshake_data_flood_ban_action, "Handshake data flood detected", iConf.handshake_data_flood_ban_time, 0, NULL);
 	}
 }
 
